@@ -59,7 +59,7 @@
 #include <KWindowSystem>
 #include <KIconLoader>
 #include <QIcon>
-#include <phonon/mediaobject.h>
+#include <QMediaPlayer>
 #include <QLabel>
 #include <QKeyEvent>
 #include <QSpinBox>
@@ -87,7 +87,10 @@ public:
         , mNotified(false)
     {
     }
-    ~ReminderTreeItem() override {}
+
+    ~ReminderTreeItem() override
+    {
+    }
 
     bool operator<(const QTreeWidgetItem &other) const override;
 
@@ -264,7 +267,7 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
 
     QWidget *suspendBox = new QWidget(topBox);
     QHBoxLayout *suspendBoxHBoxLayout = new QHBoxLayout(suspendBox);
-    suspendBoxHBoxLayout->setMargin(0);
+    suspendBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     topLayout->addWidget(suspendBox);
 
     QLabel *l = new QLabel(i18nc("@label:spinbox", "Suspend &duration:"), suspendBox);
@@ -367,8 +370,7 @@ static QString cleanSummary(const QString &summary)
     return retStr;
 }
 
-void AlarmDialog::addIncidence(const Akonadi::Item &incidenceitem, const QDateTime &reminderAt,
-                               const QString &displayText)
+void AlarmDialog::addIncidence(const Akonadi::Item &incidenceitem, const QDateTime &reminderAt, const QString &displayText)
 {
     Incidence::Ptr incidence = CalendarSupport::incidence(incidenceitem);
     ReminderTreeItem *item = searchByItem(incidenceitem);
@@ -397,8 +399,8 @@ void AlarmDialog::addIncidence(const Akonadi::Item &incidenceitem, const QDateTi
     item->setText(2, QLocale().toString(item->mTrigger, QLocale::ShortFormat));
     QString tip
         = IncidenceFormatter::toolTipStr(
-        CalendarSupport::displayName(mCalendar.data(), incidenceitem.parentCollection()),
-        incidence, item->mRemindAt.date(), true);
+              CalendarSupport::displayName(mCalendar.data(), incidenceitem.parentCollection()),
+              incidence, item->mRemindAt.date(), true);
     if (!item->mDisplayText.isEmpty()) {
         tip += QLatin1String("<br>") + item->mDisplayText;
     }
@@ -603,6 +605,18 @@ void AlarmDialog::setTimer()
     }
 }
 
+void AlarmDialog::showEvent(QShowEvent *event)
+{
+    QDialog::showEvent(event);
+    // Moving to showEvent from show() because with QDialog and Qt 5.7
+    // setOnAllDesktops seemed to work only if the dialog was already showing,
+    // which happens when a notification appears and the dialog was already
+    // up.
+    KWindowSystem::setOnAllDesktops(winId(), true);
+    KWindowSystem::unminimizeWindow(winId(), false);
+    KWindowSystem::setState(winId(), NET::KeepAbove | NET::DemandsAttention);
+}
+
 void AlarmDialog::show()
 {
     mIncidenceTree->resizeColumnToContents(0);
@@ -633,9 +647,6 @@ void AlarmDialog::show()
         setGeometry(mRect);
     }
     QDialog::show();
-    KWindowSystem::unminimizeWindow(winId(), false);
-    KWindowSystem::setState(winId(), NET::KeepAbove | NET::DemandsAttention);
-    KWindowSystem::setOnAllDesktops(winId(), true);
     if (grabFocus()) {
         KWindowSystem::activateWindow(winId());
     } else {
@@ -691,21 +702,25 @@ void AlarmDialog::eventNotification()
                 QString program = alarm->programFile();
 
                 // if the program name contains spaces escape it
-                if (program.contains(QLatin1Char(' ')) &&
-                    !(program.startsWith(QLatin1Char('\"')) &&
-                      program.endsWith(QLatin1Char('\"')))) {
+                if (program.contains(QLatin1Char(' '))
+                    && !(program.startsWith(QLatin1Char('\"'))
+                         && program.endsWith(QLatin1Char('\"')))) {
                     program = QLatin1Char('\"') + program + QLatin1Char('\"');
                 }
 
                 QProcess::startDetached(program + QLatin1Char(' ') + alarm->programArguments());
             } else if (alarm->type() == Alarm::Audio) {
                 beeped = true;
-                Phonon::MediaObject *player
-                    = Phonon::createPlayer(Phonon::NotificationCategory,
-                                           QUrl::fromLocalFile(alarm->audioFile()));
+                QMediaPlayer *player = new QMediaPlayer;
+                player->setMedia(QUrl::fromLocalFile(alarm->audioFile()));
+                player->setVolume(50);
+
                 player->setParent(this);
-                connect(player, &Phonon::MediaObject::finished, player,
-                        &Phonon::MediaObject::deleteLater);
+                connect(player, &QMediaPlayer::stateChanged, this, [this, player](QMediaPlayer::State state) {
+                    if (state == QMediaPlayer::StoppedState) {
+                        player->deleteLater();
+                    }
+                });
                 player->play();
             } else if (alarm->type() == Alarm::Email) {
                 QString from = CalendarSupport::KCalPrefs::instance()->email();
@@ -914,8 +929,8 @@ void AlarmDialog::showDetails(QTreeWidgetItem *item)
         mDetailView->setIncidence(Akonadi::Item());
     } else {
         if (!reminderItem->mDisplayText.isEmpty()) {
-            const QString txt =
-                QLatin1String("<qt><p><b>") + reminderItem->mDisplayText + QLatin1String("</b></p></qt>");
+            const QString txt
+                = QLatin1String("<qt><p><b>") + reminderItem->mDisplayText + QLatin1String("</b></p></qt>");
             mDetailView->setHeaderText(txt);
         } else {
             mDetailView->setHeaderText(QString());
@@ -946,8 +961,7 @@ void AlarmDialog::accept()
 }
 
 /** static */
-QDateTime AlarmDialog::triggerDateForIncidence(const Incidence::Ptr &incidence,
-                                               const QDateTime &reminderAt, QString &displayStr)
+QDateTime AlarmDialog::triggerDateForIncidence(const Incidence::Ptr &incidence, const QDateTime &reminderAt, QString &displayStr)
 {
     QDateTime result;
 
@@ -1012,8 +1026,7 @@ void AlarmDialog::keyPressEvent(QKeyEvent *e)
 bool AlarmDialog::openIncidenceEditorThroughKOrganizer(const Incidence::Ptr &incidence)
 {
     if (!QDBusConnection::sessionBus().interface()->isServiceRegistered(QStringLiteral(
-                                                                            "org.kde.korganizer")))
-    {
+                                                                            "org.kde.korganizer"))) {
         if (KToolInvocation::startServiceByDesktopName(QStringLiteral("org.kde.korganizer"),
                                                        QString())) {
             KMessageBox::error(
@@ -1075,8 +1088,8 @@ bool AlarmDialog::openIncidenceEditorNG(const Akonadi::Item &item)
     Incidence::Ptr incidence = CalendarSupport::incidence(item);
     IncidenceEditorNG::IncidenceDialog *dialog
         = IncidenceEditorNG::IncidenceDialogFactory::create(
-        false,     /*doesn't need initial saving*/
-        incidence->type(), nullptr, this);
+              false, /*doesn't need initial saving*/
+              incidence->type(), nullptr, this);
     dialog->load(item);
     return true;
 }
