@@ -4,7 +4,7 @@
   Copyright (c) 2003,2004 Cornelius Schumacher <schumacher@kde.org>
   Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
   Copyright (C) 2009 Sebastian Sauer <sebsauer@kdab.net>
-  Copyright (c) 2010-2018 Laurent Montel <montel@kde.org>
+  Copyright (c) 2010-2019 Laurent Montel <montel@kde.org>
   Copyright (C) 2012 Sérgio Martins <iamsergio@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
@@ -59,11 +59,7 @@
 #include <KConfigGroup>
 #include <KMessageBox>
 
-#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
-#include <KRecursiveFilterProxyModel>
-#else
 #include <QSortFilterProxyModel>
-#endif
 #include "korganizer_debug.h"
 
 #include <QAction>
@@ -333,8 +329,7 @@ public:
 
             if (hasCompatibleMimeTypes(collection)) {
                 if (collection.hasAttribute<Akonadi::EntityDisplayAttribute>()
-                    && !collection.attribute<Akonadi::EntityDisplayAttribute>()->iconName().isEmpty())
-                {
+                    && !collection.attribute<Akonadi::EntityDisplayAttribute>()->iconName().isEmpty()) {
                     return collection.attribute<Akonadi::EntityDisplayAttribute>()->icon();
                 }
             }
@@ -518,8 +513,7 @@ AkonadiCollectionView *AkonadiCollectionViewFactory::collectionView() const
     return mAkonadiCollectionView;
 }
 
-AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContextMenu,
-                                             QWidget *parent)
+AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContextMenu, QWidget *parent)
     : CalendarViewExtension(parent)
     , mActionManager(nullptr)
     , mCollectionView(nullptr)
@@ -536,7 +530,7 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
     mManagerShowCollectionProperties = new ManageShowCollectionProperties(this, this);
 
     QVBoxLayout *topLayout = new QVBoxLayout(this);
-    topLayout->setMargin(0);
+    topLayout->setContentsMargins(0, 0, 0, 0);
 
     QLineEdit *searchCol = new QLineEdit(this);
     searchCol->setToolTip(i18nc("info:tooltip", "Set search keyword"));
@@ -590,24 +584,13 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
     searchProxy->setSourceModel(collectionFilter);
     searchProxy->setObjectName(QStringLiteral("searchProxy"));
 
-#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
-    KRecursiveFilterProxyModel *filterTreeViewModel = new KRecursiveFilterProxyModel(this);
-    filterTreeViewModel->setDynamicSortFilter(true);
-    filterTreeViewModel->setSourceModel(searchProxy);
-    filterTreeViewModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
-//   filterTreeViewModel->setObjectName( "Recursive filtering, for the search bar" );
-    connect(searchCol, &QLineEdit::textChanged, filterTreeViewModel,
-            &KRecursiveFilterProxyModel::setFilterWildcard);
-#else
     QSortFilterProxyModel *filterTreeViewModel = new QSortFilterProxyModel(this);
     filterTreeViewModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
     filterTreeViewModel->setRecursiveFilteringEnabled(true);
     filterTreeViewModel->setDynamicSortFilter(true);
     filterTreeViewModel->setSourceModel(searchProxy);
-//   filterTreeViewModel->setObjectName( "Recursive filtering, for the search bar" );
     connect(searchCol, &QLineEdit::textChanged, filterTreeViewModel,
             &QSortFilterProxyModel::setFilterWildcard);
-#endif
 
     SortProxyModel *searchSortProxy = new SortProxyModel(this);
     searchSortProxy->setSourceModel(filterTreeViewModel);
@@ -653,7 +636,7 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
 
         mActionManager
             = new Akonadi::StandardCalendarActionManager(
-            xmlclient->actionCollection(), mCollectionView);
+                  xmlclient->actionCollection(), mCollectionView);
 
         QList<Akonadi::StandardActionManager::Type> standardActions;
         standardActions << Akonadi::StandardActionManager::CreateCollection
