@@ -33,8 +33,7 @@ public:
     explicit StyledCalendarDelegate(QObject *parent);
     ~StyledCalendarDelegate() override;
 
-    void paint(QPainter *painter, const QStyleOptionViewItem &option,
-               const QModelIndex &index) const override;
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
     QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
     enum Action {
@@ -49,8 +48,7 @@ Q_SIGNALS:
     void action(const QModelIndex &, int);
 
 protected:
-    bool editorEvent(QEvent *event, QAbstractItemModel *model, const QStyleOptionViewItem &option,
-                     const QModelIndex &index) override;
+    bool editorEvent(QEvent *event, QAbstractItemModel *model, const QStyleOptionViewItem &option, const QModelIndex &index) override;
 
 private:
     QList<Action> getActions(const QStyleOptionViewItem &option, const QModelIndex &index) const;
